﻿using System;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Collections.ObjectModel;
using System.IO;
using System.Text;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            double x = 12075256; 
            double y = 1851610;
            addGoogleBasedMap();
            addVesselLayer();
            Map1.CurrentScale = 9000000; 
            Map1.CenterAt(x, y);
        }
    }

    private void addGoogleBasedMap()
    {
        Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
        Map1.MapUnit = GeographyUnit.Meter;
        Map1.MapTools.MouseCoordinate.Enabled = true;
        Map1.MapTools.MouseMapTool.Enabled = true;
        Map1.MapTools.ScaleLine.Enabled = true;
        Map1.MapTools.PanZoomBar.Enabled = true;
        Map1.MapTools.Logo.Enabled = false;

        int hight = 505;
        int width = 1050;

        Map1.Height = hight;
        Map1.Width = width;

        GoogleOverlay google = new GoogleOverlay("Google Map");
        google.JavaScriptLibraryUri = new Uri(ConfigurationManager.AppSettings["GoogleUri"]);
        google.GoogleMapType = GoogleMapType.Normal;

        Map1.CustomOverlays.Add(google);
    }

    private void addVesselLayer()
    {
        SimpleMarkerOverlay vesselMarker = new SimpleMarkerOverlay("VesselMarker");
        vesselMarker.Click += new EventHandler<MarkerOverlayClickEventArgs>(markerOverlay_Click);
        vesselMarker.IsBaseOverlay = false;
        Map1.CustomOverlays.Add(vesselMarker);
    }

    void markerOverlay_Click(object sender, MarkerOverlayClickEventArgs e)
    {
    }
    protected void Button1_Click(object sender, EventArgs e)
    {
        Collection<Feature> features = getDataFromFile();
        addMarkers(features);
    }

    private Collection<Feature> getDataFromFile()
    {
        Collection<Feature> r = new Collection<Feature>();
        string path = System.IO.Path.Combine(MapPath("App_Data"), "data.sql");
        String[] lineValues = File.ReadAllLines(path);
        for (int i = 0; i < lineValues.Length; i++)
        {
            String line = lineValues[i];
            String[] items = line.Split(',');
            String id = items[0];
            String typeId = items[1];
            String cog = items[2];
            double lon = Convert.ToDouble(items[3]);
            double lat = Convert.ToDouble(items[4]);
            String statusId = items[5];
            Feature feature = new Feature(lon,lat,id);
            feature.ColumnValues.Add("TypeId", typeId);
            feature.ColumnValues.Add("StatusId", typeId);
            feature.ColumnValues.Add("Cog", typeId);
            r.Add(feature);
        }
        return r;
    }

    private void addMarkers(Collection<Feature> features)
    {
        SimpleMarkerOverlay vesselMarker = (SimpleMarkerOverlay)Map1.CustomOverlays["VesselMarker"];
        vesselMarker.Markers.Clear();

        foreach (Feature feature in features)
        {
            Feature targetFeature = convertProjection(feature);
            Marker vessel = new Marker();
            vessel.Id = targetFeature.Id;
            vessel.Position = (PointShape)targetFeature.GetShape();
            int statusId = int.Parse(targetFeature.ColumnValues["StatusId"]);
            int vesselTypeId = int.Parse(targetFeature.ColumnValues["TypeId"]);
            vessel.WebImage = new WebImage(getPathIcon(statusId, vesselTypeId), 18, 18, -9, -9);
            vessel.WebImage.RotationAngle = -float.Parse(targetFeature.ColumnValues["Cog"]);
            StringBuilder contentHtml = new StringBuilder();
            contentHtml.Append("<div class='popup'>")
                .Append(targetFeature.Id);
            vessel.Popup.ContentHtml = contentHtml.ToString();
            vessel.Popup.Width = 100;
            vessel.Popup.Height = 20;
            vesselMarker.Markers.Add(vessel);
        }
    }

    private Feature convertProjection(Feature featureS)
    {
        Feature result = new Feature();
        Proj4Projection proj4Projection = new Proj4Projection();
        proj4Projection.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);  
        proj4Projection.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
        proj4Projection.Open();
        result = proj4Projection.ConvertToExternalProjection(featureS);
        return result;
    }

    private string getPathIcon(int statusId, int vesselTypeId)
    {
        if (statusId == 1 || statusId == 5)
        {
            return "theme/default/markers/anchor_moored.png";
        }
        else
        {
            if (vesselTypeId >= 60 && vesselTypeId <= 69)
            {
                return "theme/default/markers/passenger.png";
            }
            if (vesselTypeId >= 70 && vesselTypeId <= 79)
            {
                return "theme/default/markers/cargo.png";
            }
            if (vesselTypeId >= 80 && vesselTypeId <= 89)
            {
                return "theme/default/markers/tanker.png";
            }
            if ((vesselTypeId >= 50 && vesselTypeId <= 59) || vesselTypeId == 10)
            {
                return "theme/default/markers/tug_pilot.png";
            }
            if (vesselTypeId >= 40 && vesselTypeId <= 49)
            {
                return "theme/default/markers/hight_speed_craft.png";
            }
            return "theme/default/markers/yacht.png";
        }
    }
}
